@@ -13,6 +13,11 @@ import aws_cdk.aws_logs
 import aws_cdk.core
 import aws_cdk.cx_api
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53", "1.36.0", __name__[0:-6], "aws-route53@1.36.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
